@@ -38,22 +38,22 @@ class Cardinality(Enum):
     @property
     def many_left(self) -> bool:
         """Many-relationship on the left, ``True`` for ``N:1`` and ``M:N``."""
-        return self == Cardinality.ManyToMany or self == Cardinality.ManyToOne  # pragma: no cover
+        return self == Cardinality.ManyToMany or self == Cardinality.ManyToOne
 
     @property
     def many_right(self) -> bool:
         """Many-relationship on the right, ``True`` for ``1:N`` and ``M:N``."""
-        return self == Cardinality.ManyToMany or self == Cardinality.OneToMany  # pragma: no cover
+        return self == Cardinality.ManyToMany or self == Cardinality.OneToMany
 
     @property
     def one_left(self) -> bool:
         """One-relationship on the left, ``True`` for ``1:1`` and ``1:N``."""
-        return not self.many_left  # pragma: no cover
+        return not self.many_left
 
     @property
     def one_right(self) -> bool:
         """One-relationship on the right, ``True`` for ``1:1`` and ``N:1``."""
-        return not self.many_right  # pragma: no cover
+        return not self.many_right
 
     @property
     def inverse(self) -> "Cardinality":
