@@ -15,8 +15,10 @@ from typing import Dict, Generator, Generic as _Generic, Iterable, List, Optiona
 import numpy as np
 import pandas as pd
 
-from rics.mapping import Cardinality as _Cardinality, DirectionalMapping as _DirectionalMapping
-from rics.mapping.types import CandidateType, ValueType
+from ._cardinality import Cardinality as _Cardinality
+from ._directional_mapping import DirectionalMapping as _DirectionalMapping
+from .exceptions import AmbiguousScoreError as _AmbiguousScoreError
+from .types import CandidateType, ValueType
 
 _MAPPER_LOGGER = logging.getLogger(__package__).getChild("Mapper")
 ACCEPT_LOGGER = _MAPPER_LOGGER.getChild("accept")
@@ -62,7 +64,7 @@ class MatchScores:
         """Create a ``DirectionalMapping`` with a given target ``Cardinality``.
 
         Args:
-            cardinality: Explicit cardinality to set, see :attr:`~rics.mapping.DirectionalMapping.cardinality`. If
+            cardinality: Explicit cardinality to set, see :attr:`~.DirectionalMapping.cardinality`. If
                 ``None``, use the actual cardinality when selecting all matches with scores :attr:`above` the minimum.
 
         Returns:
@@ -169,7 +171,7 @@ class MatchScores:
         superseding_value: Optional["MatchScores.Record[ValueType, CandidateType]"] = None
         superseding_candidate: Optional["MatchScores.Record[ValueType, CandidateType]"] = None
 
-        def explain(self, min_score: float, full: bool = False) -> str:  # pragma: no cover
+        def explain(self, min_score: float, full: bool = False) -> str:
             """Create a string which explains the rejection.
 
             Args:
@@ -202,6 +204,32 @@ class MatchScores:
 
             return f"{self.record}{why}."
 
+    def _raise_if_ambiguous(
+        self,
+        record: Record,  # type: ignore[type-arg]
+        matches: Dict,  # type: ignore[type-arg]
+        kind: str,
+        cardinality: _Cardinality,
+    ) -> None:
+        if record.score == np.inf:
+            # Overrides are allowed to be infinite; the first one will be chosen. It's up to the user to manage them.
+            return
+
+        key = record.value if kind == "value" else record.candidate
+        if key not in matches:
+            return
+
+        old_match = matches[key]
+        if record.score == old_match.score:
+            raise _AmbiguousScoreError(
+                kind=kind,
+                key=key,
+                match0=record,
+                match1=old_match,
+                cardinality=cardinality.name,
+                scores=self._matrix.to_string(),
+            )
+
     def _select_one_to_one(
         self,
         records: Iterable[Record[ValueType, CandidateType]],
@@ -211,8 +239,11 @@ class MatchScores:
         mcs: Dict[CandidateType, MatchScores.Record[ValueType, CandidateType]] = {}
 
         for record in records:
+            self._raise_if_ambiguous(record, mcs, "candidate", _Cardinality.OneToOne)
+            self._raise_if_ambiguous(record, mvs, "value", _Cardinality.OneToOne)
+
             if record.score < self._min_score or record.value in mvs or record.candidate in mcs:
-                if rejections is not None:  # pragma: no cover
+                if rejections is not None:
                     rejections.append(
                         MatchScores.Reject(
                             record,
@@ -233,8 +264,10 @@ class MatchScores:
         mcs: Dict[CandidateType, MatchScores.Record[ValueType, CandidateType]] = {}
 
         for record in records:
+            self._raise_if_ambiguous(record, mcs, "candidate", _Cardinality.OneToMany)
+
             if record.score < self._min_score or record.candidate in mcs:
-                if rejections is not None:  # pragma: no cover
+                if rejections is not None:
                     rejections.append(MatchScores.Reject(record, superseding_candidate=mcs.get(record.candidate)))
                 continue
             mcs[record.candidate] = record
@@ -248,8 +281,10 @@ class MatchScores:
         mvs: Dict[ValueType, MatchScores.Record[ValueType, CandidateType]] = {}
 
         for record in records:
+            self._raise_if_ambiguous(record, mvs, "value", cardinality=_Cardinality.ManyToOne)
+
             if record.score < self._min_score or record.value in mvs:
-                if rejections is not None:  # pragma: no cover
+                if rejections is not None:
                     rejections.append(MatchScores.Reject(record, superseding_value=mvs.get(record.value)))
                 continue
             mvs[record.value] = record
@@ -260,7 +295,7 @@ class MatchScores:
         records: Iterable[Record[ValueType, CandidateType]],
         rejections: List[Reject[ValueType, CandidateType]] = None,
     ) -> Iterable[Record[ValueType, CandidateType]]:
-        for record in records:  # pragma: no cover
+        for record in records:
             if record.score < self._min_score:
                 if rejections is not None:
                     rejections.append(MatchScores.Reject(record))
