@@ -10,7 +10,6 @@ from pathlib import Path as _Path
 from typing import Any, Optional
 
 import click
-import pkg_resources
 
 from .._just_the_way_i_like_it import configure_stuff as _configure_stuff
 from ._util import get_best as _get_best
@@ -114,7 +113,7 @@ def main(time_per_candidate: float, name: str, create: bool, per_candidate: bool
         name = "create-example-run"
         for template_name in "candidates", "test_data":
             path = _Path().joinpath(template_name).with_suffix(".py").absolute()
-            if path.exists():  # pragma: no cover
+            if path.exists():
                 click.secho(
                     f"ABORT: Refusing to overwrite existing file '{path}'. "
                     f"Delete files 'candidates.py' and 'test_data.py' in '{path.parent}' to continue.",
@@ -122,8 +121,8 @@ def main(time_per_candidate: float, name: str, create: bool, per_candidate: bool
                     err=True,
                 )
                 sys.exit(1)
-            data: bytes = pkg_resources.resource_string(__package__, f"templates/{template_name}.py.txt")
-            path.write_bytes(data)
+            text = _Path(__file__).parent.joinpath(f"templates/{template_name}.py.txt").read_text()
+            path.write_text(text)
 
     name_path = _Path(name).absolute()
     pretty = name_path.stem.replace("-", " ").replace("_", " ").title()
@@ -184,7 +183,7 @@ def main(time_per_candidate: float, name: str, create: bool, per_candidate: bool
     click.secho(f"Figure saved: '{figure_path}'", fg="green")
 
     performance_report_path = name_path.with_suffix(".csv")
-    if len(result) > 10000:  # pragma: no cover
+    if len(result) > 10000:
         click.secho(
             f"WARNING: The full timing report has {len(result)} rows, which may take a while to serialize.", fg="yellow"
         )
